@@ -1,6 +1,6 @@
 /*
  * Fisoco, a FInding SOrting and COnverting free software
- * Copyright 2015 Félicien PILLOT <felicien.pillot@member.fsf.org>
+ * Copyright 2015-2016 (C) Felicien PILLOT <felicien.pillot@member.fsf.org>
  *
  * This file is part of Fisoco.
  *
@@ -42,8 +42,9 @@
 #include <thread> 
 #include <X11/Xlib.h>
 // Fisoco headers
-#include "../include/gui.h"
 #include "../include/cli.h"
+#include "../include/global.h"
+#include "../include/gui.h"
 #include "../include/main.h"
 
 using namespace std;
@@ -62,6 +63,13 @@ struct Fisoco : Gtk::Application {
         cli_opt.set_long_name ("cli");
         cli_opt.set_description (gettext ("Use Command Line Interface (CLI) mode"));
         group.add_entry (cli_opt, show_cli);
+        // Debug option
+        bool activate_dbg = false;
+        Glib::OptionEntry dbg_opt;
+        dbg_opt.set_short_name ('d');
+        dbg_opt.set_long_name ("debug");
+        dbg_opt.set_description (gettext ("Output debug messages"));
+        group.add_entry (dbg_opt, activate_dbg);
         // Version option
         bool show_ver = false;
         Glib::OptionEntry ver_opt;
@@ -77,24 +85,26 @@ struct Fisoco : Gtk::Application {
         int argc;
         char **argv = cmd->get_arguments (argc);
         context.parse (argc, argv);
+        
+        // manage debug mode
+        activate_debug (activate_dbg);
+        
         // maybe show the gui (if show_cli stay false)
-        if (!show_cli)
-        {
-            if (show_ver)
-                version ();
-            else
-                activate ();
-        }
+        if (show_ver)
+            version ();
+        else if (show_cli)
+            Show_cli ();
         else
-        {
-            Cli *main;
-            main = new Cli ();
-        }
+            Show_gui ();
         return 0;
     }
-    void on_activate() {
-        // can't use Gtk::manage, so we have to keep
-        // the reference or the main loop quits.
+    void Show_cli ()
+    {
+        Cli *main;
+        main = new Cli ();
+    }
+    void Show_gui ()
+    {
         Gui *main;
         main = new Gui ();
         add_window(*main);
@@ -112,14 +122,18 @@ main (int argc, char* argv[])
     textdomain ( PACKAGE);
     /* graphical interface */
     XInitThreads ();
+    if (isatty(fileno(stdin)))
+        debug (gettext ("STDIN is a terminal"));
+    else
+        debug (gettext ("STDIN is a file or a pipe"));
     return Fisoco ().run (argc, argv);
 }
 
 void
 version ()
 {
-    printf ("Fisoco  Copyright  (C) 2015  Felicien PILLOT <felicien.pillot@member.fsf.org>\n");
-    printf (gettext ("This program comes with ABSOLUTELY NO WARRANTY; for details use -w option.\n"));
-    printf (gettext ("This is free software, and you are welcome to redistribute\n"));
-    printf (gettext ("it under certain condition (option -c for details).\n"));
+    std::cout << "Fisoco  Copyright  (C) 2015  Felicien PILLOT <felicien.pillot@member.fsf.org>" << std::endl;
+    std::cout << gettext ("This program comes with ABSOLUTELY NO WARRANTY; for details use -w option.") << std::endl;
+    std::cout << gettext ("This is free software, and you are welcome to redistribute") << std::endl;
+    std::cout << gettext ("it under certain condition (option -c for details).") << std::endl;
 }
